## Installation
```
$ pip install git+https://github.com/JoMingyu/opgg-helper.git
```

## Usage
```
$ opgg 미드 이렐리아
$ opgg mid irelia
$ opgg 미드 이렐
$ opgg 이렐 미드
$ opgg 이렐 ㅁㄷ
$ opgg ㅅㅍ 파이크
$ opgg 자야 .
# -> The position with the highest selection percentage for the champion is automatically selected
```  

### Console Mode
```
$ opgg 미드 카서스 -c
■		정밀
□ □ ■ □		기민한 발놀림
□ ■ □		승전보
■ □ □		전설
■ □ □		최후의 일격

■		마법
□ □ □
□ ■ □		기민함
□ □ ■		폭풍의 결집

□ ■ □		공격속도 +9%
■ □ □		적응형으로 공격력 +6 또는 주문력 +10
■ □ □		체력 +15 ~ 90 (레벨에 비례)

# -> It colored on console.
```